@@ -1,6 +1,6 @@
 package App::nup;
 
-our $VERSION = "0.9904";
+our $VERSION = "0.9905";
 
 1;
 =encoding utf-8
@@ -14,32 +14,33 @@ nup - N-up multi-column paged output for commands and files
     nup [ options ] file ...
     nup -e [ options ] command ...
 
-      -h, --help             show help
-          --version          show version
-      -d, --debug            debug mode
-      -n, --dryrun           dry-run mode
-      -e, --exec             execute command mode
-      -V, --parallel         parallel view mode
-      -F, --fold             fold mode (disable page mode)
-      -H, --filename         show filename headers (default: on)
-      -G, --grid=#           grid layout (e.g., 2x3)
-      -C, --pane=#           number of columns
-      -R, --row=#            number of rows
-      -P, --page=#           page height in lines
-      -S, --pane-width=#     pane width (default: 85)
-    --bs, --border-style=#   border style (default: heavy-box)
-    --ls, --line-style=#     line style (none/truncate/wrap/wordwrap)
-    --cm, --colormap=#       color mapping (LABEL=COLOR)
-          --white-board      black on white board
-          --black-board      white on black board
-          --green-board      white on green board
-          --slate-board      white on dark slate board
-          --pager=#          pager command (empty to disable)
-          --no-pager         disable pager
+     -h  --help             show help
+         --version          show version
+     -d  --debug            debug mode
+     -n  --dryrun           dry-run mode
+     -e  --exec             execute command mode
+         --alias=CMD=OPTS   set command alias
+     -V  --parallel         parallel view mode
+     -F  --fold             fold mode (disable page mode)
+     -H  --filename         show filename headers (default: on)
+     -G  --grid=#           grid layout (e.g., 2x3)
+     -C  --pane=#           number of columns
+     -R  --row=#            number of rows
+     -P  --page=#           page height in lines
+     -S  --pane-width=#     pane width (default: 85)
+    --bs --border-style=#   border style (default: heavy-box)
+    --ls --line-style=#     line style (none/truncate/wrap/wordwrap)
+    --cm --colormap=#       color mapping (LABEL=COLOR)
+         --pager=#          pager command (empty to disable)
+         --no-pager         disable pager
+         --white-board      black on white board
+         --black-board      white on black board
+         --green-board      white on green board
+         --slate-board      white on dark slate board
 
 =head1 VERSION
 
-Version 0.9904
+Version 0.9905
 
 =cut
 =head1 DESCRIPTION
@@ -86,6 +87,22 @@ Dry-run mode. Show the command without executing.
 Force command execution mode. Normally the mode is auto-detected,
 but use this option when you want to execute a file as a command.
 
+=item B<--alias>=I<CMD>=I<OPTS>
+
+Set command-specific options. When a command matches I<CMD>, the
+specified I<OPTS> are automatically added to the command line.
+Multiple C<--alias> options can be specified.
+
+Default aliases:
+
+    bat    --style=plain --color=always
+    rg     --color=always
+    tree   -C
+
+Example:
+
+    nup --alias='grep=--color=always' grep pattern file
+
 =item B<-V>, B<--parallel>
 
 Enable parallel view mode for ansicolumn.  In this mode, each file
